@@ -831,7 +831,7 @@ outlierplot <- function(X,...) UseMethod("outlierplot",X)
 ## general function to obtain exploratory plots on the outlier character of the sample
 outlierplot.acomp <- function(X,colcode=colorsForOutliers1,pchcode=pchForOutliers1,
   type=c("scatter","biplot","dendrogram","ecdf","portion","nout"),
-  legend.position,pch=19,...,clusterMethod="compact",
+  legend.position,pch=19,...,clusterMethod="ward",
   myCls=classifier(X,alpha=alpha,type=class.type,corrected=corrected),
   classifier=OutlierClassifier1,
   alpha=0.05,
